/* Indented to avoid "suggest hiding ..." warnings.   */
 #pragma GCC system_header

#define sys_uint 1U
#define sys_str(x) x
#define sys_foo(x, y...) bar (x, ##y)

#define sys_uint 1U
#define sys_fl 1.0f
#define sys_ld 1.0L
