/* This is just 920730-1.c compiled with -traditional.
   See 920730-1t.x.  */

/* It is necessary to undefine __GNUC__ in order to prevent glibc 2.2's
   sys/cdefs.h from issuing an #error.  Do Not Ask.  */
#undef __GNUC__

#include "920730-1.c"
